@@ -17,4 +17,13 @@ defmodule ModPresenceDemo do
     info('Receive presence for #{user}')
     :none
   end
+
+  def depends(_host, _opts) do
+    []
+  end
+
+  def mod_options(_host) do
+    []
+  end
+  
 end
