@@ -5,7 +5,7 @@
 %%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -33,7 +33,7 @@
 	 set_password/3, check_password/4,
 	 check_password/6, check_password_with_authmodule/4,
 	 check_password_with_authmodule/6, try_register/3,
-	 get_users/0, get_users/1, password_to_scram/1,
+	 get_users/0, get_users/1, password_to_scram/2,
 	 get_users/2, import_info/0,
 	 count_users/1, import/5, import_start/2,
 	 count_users/2, get_password/2,
@@ -48,7 +48,7 @@
 
 -export([auth_modules/1, convert_to_scram/1]).
 
--include("scram.hrl").
+-include_lib("xmpp/include/scram.hrl").
 -include("logger.hrl").
 
 -define(SALT_LENGTH, 16).
@@ -197,16 +197,21 @@ plain_password_required(Server) ->
 
 -spec store_type(binary()) -> plain | scram | external.
 store_type(Server) ->
-    lists:foldl(
-      fun(_, external) -> external;
-	 (M, scram) ->
-	      case M:store_type(Server) of
-		  external -> external;
-		  _ -> scram
-	      end;
-	 (M, plain) ->
-	      M:store_type(Server)
-      end, plain, auth_modules(Server)).
+    case auth_modules(Server) of
+	[ejabberd_auth_anonymous] -> external;
+	Modules ->
+	    lists:foldl(
+		fun(ejabberd_auth_anonymous, Type) -> Type;
+		   (_, external) -> external;
+		   (M, scram) ->
+		       case M:store_type(Server) of
+			   external -> external;
+			   _ -> scram
+		       end;
+		   (M, plain) ->
+		       M:store_type(Server)
+		end, plain, Modules)
+    end.
 
 -spec check_password(binary(), binary(), binary(), binary()) -> boolean().
 check_password(User, AuthzId, Server, Password) ->
@@ -554,7 +559,7 @@ db_try_register(User, Server, Password, Mod) ->
     case erlang:function_exported(Mod, try_register, 3) of
 	true ->
 	    Password1 = case Mod:store_type(Server) of
-			    scram -> password_to_scram(Password);
+			    scram -> password_to_scram(Server, Password);
 			    _ -> Password
 			end,
 	    Ret = case use_cache(Mod, Server) of
@@ -579,7 +584,7 @@ db_set_password(User, Server, Password, Mod) ->
     case erlang:function_exported(Mod, set_password, 3) of
 	true ->
 	    Password1 = case Mod:store_type(Server) of
-			    scram -> password_to_scram(Password);
+			    scram -> password_to_scram(Server, Password);
 			    _ -> Password
 			end,
 	    Ret = case use_cache(Mod, Server) of
@@ -605,6 +610,7 @@ db_get_password(User, Server, Mod) ->
 	false when UseCache ->
 	    case ets_cache:lookup(cache_tab(Mod), {User, Server}) of
 		{ok, exists} -> error;
+		not_found -> error;
 		Other -> Other
 	    end;
 	false ->
@@ -621,20 +627,29 @@ db_user_exists(User, Server, Mod) ->
     case db_get_password(User, Server, Mod) of
 	{ok, _} ->
 	    true;
+	not_found ->
+	    false;
 	error ->
 	    case {Mod:store_type(Server), use_cache(Mod, Server)} of
 		{external, true} ->
-		    case ets_cache:lookup(
-			   cache_tab(Mod), {User, Server},
-			   fun() ->
-				   case Mod:user_exists(User, Server) of
-				       {CacheTag, true} -> {CacheTag, {ok, exists}};
-				       {CacheTag, false} -> {CacheTag, error};
-				       {_, {error, _}} = Err -> Err
-				   end
-			   end) of
+		    Val = case ets_cache:lookup(cache_tab(Mod), {User, Server}, error) of
+			      error ->
+				  ets_cache:update(cache_tab(Mod), {User, Server}, {ok, exists},
+						   fun() ->
+							   case Mod:user_exists(User, Server) of
+							       {CacheTag, true} -> {CacheTag, {ok, exists}};
+							       {CacheTag, false} -> {CacheTag, not_found};
+							       {_, {error, _}} = Err -> Err
+							   end
+						   end);
+			      Other ->
+				  Other
+			  end,
+		    case Val of
 			{ok, _} ->
 			    true;
+			not_found ->
+			    false;
 			error ->
 			    false;
 			{error, _} = Err ->
@@ -743,25 +758,28 @@ is_password_scram_valid(Password, Scram) ->
 	    false;
 	_ ->
 	    IterationCount = Scram#scram.iterationcount,
+	    Hash = Scram#scram.hash,
 	    Salt = base64:decode(Scram#scram.salt),
-	    SaltedPassword = scram:salted_password(Password, Salt, IterationCount),
-	    StoredKey =	scram:stored_key(scram:client_key(SaltedPassword)),
+	    SaltedPassword = scram:salted_password(Hash, Password, Salt, IterationCount),
+	    StoredKey =	scram:stored_key(Hash, scram:client_key(Hash, SaltedPassword)),
 	    base64:decode(Scram#scram.storedkey) == StoredKey
     end.
 
-password_to_scram(Password) ->
-    password_to_scram(Password, ?SCRAM_DEFAULT_ITERATION_COUNT).
+password_to_scram(Host, Password) ->
+    password_to_scram(Host, Password, ?SCRAM_DEFAULT_ITERATION_COUNT).
 
-password_to_scram(#scram{} = Password, _IterationCount) ->
+password_to_scram(_Host, #scram{} = Password, _IterationCount) ->
     Password;
-password_to_scram(Password, IterationCount) ->
+password_to_scram(Host, Password, IterationCount) ->
+    Hash = ejabberd_option:auth_scram_hash(Host),
     Salt = p1_rand:bytes(?SALT_LENGTH),
-    SaltedPassword = scram:salted_password(Password, Salt, IterationCount),
-    StoredKey = scram:stored_key(scram:client_key(SaltedPassword)),
-    ServerKey = scram:server_key(SaltedPassword),
+    SaltedPassword = scram:salted_password(Hash, Password, Salt, IterationCount),
+    StoredKey = scram:stored_key(Hash, scram:client_key(Hash, SaltedPassword)),
+    ServerKey = scram:server_key(Hash, SaltedPassword),
     #scram{storedkey = base64:encode(StoredKey),
 	   serverkey = base64:encode(ServerKey),
 	   salt = base64:encode(Salt),
+	   hash = Hash,
 	   iterationcount = IterationCount}.
 
 %%%----------------------------------------------------------------------
@@ -928,7 +946,7 @@ convert_to_scram(Server) ->
 		fun({U, S}) ->
 		    case get_password(U, S) of
 			Pass when is_binary(Pass) ->
-			    SPass = password_to_scram(Pass),
+			    SPass = password_to_scram(Server, Pass),
 			    set_password(U, S, SPass);
 			_ ->
 			    ok
