@@ -1,5 +1,5 @@
 %%%----------------------------------------------------------------------
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -79,6 +79,8 @@ opt_type(auth_opts) ->
     end;
 opt_type(auth_password_format) ->
     econf:enum([plain, scram]);
+opt_type(auth_scram_hash) ->
+    econf:enum([sha, sha256, sha512]);
 opt_type(auth_use_cache) ->
     econf:bool();
 opt_type(c2s_cafile) ->
@@ -245,6 +247,8 @@ opt_type(oauth_cache_life_time) ->
     econf:timeout(second, infinity);
 opt_type(oauth_cache_missed) ->
     econf:bool();
+opt_type(oauth_cache_rest_failure_life_time) ->
+    econf:timeout(second, infinity);
 opt_type(oauth_cache_size) ->
     econf:pos_int(infinity);
 opt_type(oauth_db_type) ->
@@ -271,6 +275,10 @@ opt_type(outgoing_s2s_families) ->
 		   (ipv6) -> inet6
 		end, L)
       end);
+opt_type(outgoing_s2s_ipv4_address) ->
+    econf:ipv4();
+opt_type(outgoing_s2s_ipv6_address) ->
+    econf:ipv6();
 opt_type(outgoing_s2s_port) ->
     econf:port();
 opt_type(outgoing_s2s_timeout) ->
@@ -371,6 +379,8 @@ opt_type(sql_keepalive_interval) ->
     econf:timeout(second);
 opt_type(sql_password) ->
     econf:binary();
+opt_type(sql_odbc_driver) ->
+    econf:binary();
 opt_type(sql_pool_size) ->
     econf:pos_int();
 opt_type(sql_port) ->
@@ -511,6 +521,7 @@ options() ->
       fun(Host) -> [ejabberd_config:default_db(Host, ejabberd_auth)] end},
      {auth_opts, []},
      {auth_password_format, plain},
+     {auth_scram_hash, sha},
      {auth_use_cache,
       fun(Host) -> ejabberd_config:get_option({use_cache, Host}) end},
      {c2s_cafile, undefined},
@@ -577,6 +588,7 @@ options() ->
       fun(Host) -> ejabberd_config:get_option({cache_missed, Host}) end},
      {oauth_cache_size,
       fun(Host) -> ejabberd_config:get_option({cache_size, Host}) end},
+     {oauth_cache_rest_failure_life_time, infinity},
      {oauth_db_type,
       fun(Host) -> ejabberd_config:default_db(Host, ejabberd_oauth) end},
      {oauth_expire, 4294967},
@@ -587,6 +599,8 @@ options() ->
      {oom_queue, 10000},
      {oom_watermark, 80},
      {outgoing_s2s_families, [inet, inet6]},
+     {outgoing_s2s_ipv4_address, undefined},
+     {outgoing_s2s_ipv6_address, undefined},
      {outgoing_s2s_port, 5269},
      {outgoing_s2s_timeout, timer:seconds(10)},
      {pam_service, <<"ejabberd">>},
@@ -645,6 +659,7 @@ options() ->
      {sql_database, undefined},
      {sql_keepalive_interval, undefined},
      {sql_password, <<"">>},
+     {sql_odbc_driver, <<"libtdsodbc.so">>}, % default is FreeTDS driver
      {sql_pool_size,
       fun(Host) ->
 	      case ejabberd_config:get_option({sql_type, Host}) of
@@ -714,6 +729,7 @@ globals() ->
      oauth_cache_life_time,
      oauth_cache_missed,
      oauth_cache_size,
+     oauth_cache_rest_failure_life_time,
      oauth_db_type,
      oauth_expire,
      oauth_use_cache,
