@@ -5,7 +5,7 @@
 %%% Created :  7 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -52,7 +52,7 @@
 -export([get_info_s2s_connections/1]).
 
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("ejabberd_commands.hrl").
 -include_lib("stdlib/include/ms_transform.hrl").
 -include("ejabberd_stacktrace.hrl").
@@ -351,8 +351,11 @@ route(Packet) ->
 	{ok, Pid} when is_pid(Pid) ->
 	    ?DEBUG("Sending to process ~p~n", [Pid]),
 	    #jid{lserver = MyServer} = From,
-	    ejabberd_hooks:run(s2s_send_packet, MyServer, [Packet]),
-	    ejabberd_s2s_out:route(Pid, Packet);
+	    case ejabberd_hooks:run_fold(s2s_send_packet, MyServer, Packet,
+					 []) of
+		drop -> ok;
+		Packet1 -> ejabberd_s2s_out:route(Pid, Packet1)
+	    end;
 	{error, Reason} ->
 	    Lang = xmpp:get_lang(Packet),
 	    Err = case Reason of
