@@ -5,7 +5,7 @@
 %%% Created : 22 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -96,7 +96,7 @@ init([Host]) ->
         sqlite ->
             check_sqlite_db(Host);
 	mssql ->
-	    ejabberd_sql:init_mssql();
+	    ejabberd_sql:init_mssql(Host);
         _ ->
             ok
     end,
