@@ -33,7 +33,7 @@
 %%% NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 %%% POSSIBILITY OF SUCH DAMAGE.
 %%% ==========================================================================================================
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%----------------------------------------------------------------------
 
 -module(ejabberd_websocket).
@@ -45,7 +45,7 @@
 
 -include("logger.hrl").
 
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 
 -include("ejabberd_http.hrl").
 
@@ -225,6 +225,16 @@ ws_loop(FrameInfo, Socket, WsHandleLoopPid, SocketMode, Shaper) ->
                    end,
             erlang:demonitor(Ref),
             websocket_close(Socket, WsHandleLoopPid, SocketMode, Code);
+        {text_with_reply, Data, Sender} ->
+            SocketMode:send(Socket, encode_frame(Data, 1)),
+            Sender ! {text_reply, self()},
+            ws_loop(FrameInfo, Socket, WsHandleLoopPid,
+                    SocketMode, Shaper);
+        {data_with_reply, Data, Sender} ->
+            SocketMode:send(Socket, encode_frame(Data, 2)),
+            Sender ! {data_reply, self()},
+            ws_loop(FrameInfo, Socket, WsHandleLoopPid,
+                    SocketMode, Shaper);
         {text, Data} ->
             SocketMode:send(Socket, encode_frame(Data, 1)),
             ws_loop(FrameInfo, Socket, WsHandleLoopPid,
