@@ -5,7 +5,7 @@
 %%% Created : 10 Aug 2008 by Badlop <badlop@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -85,7 +85,7 @@
 -include("mod_roster.hrl").
 -include("mod_privacy.hrl").
 -include("ejabberd_sm.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 
 %%%
 %%% gen_mod
@@ -135,7 +135,7 @@ get_commands_spec() ->
 	"* ORG ORGUNIT  - Work: Department\n",
 
     VcardXEP = "For a full list of vCard fields check XEP-0054: vcard-temp at "
-	"http://www.xmpp.org/extensions/xep-0054.html",
+	"https://xmpp.org/extensions/xep-0054.html",
 
     [
      #ejabberd_commands{name = compile, tags = [erlang],
@@ -1478,7 +1478,7 @@ srg_user_del(User, Host, Group, GroupHost) ->
 %%% Stanza
 %%%
 
-%% @doc Send a message to a Jabber account.
+%% @doc Send a message to an XMPP account.
 %% @spec (Type::binary(), From::binary(), To::binary(), Subject::binary(), Body::binary()) -> ok
 send_message(Type, From, To, Subject, Body) ->
     CodecOpts = ejabberd_config:codec_options(),
@@ -1494,10 +1494,15 @@ send_message(Type, From, To, Subject, Body) ->
                       #xmlel{name = <<"body">>,
                              children = [{xmlcdata, Body}]}]},
           ?NS_CLIENT, CodecOpts) of
-        #message{from = JID} = Msg ->
+        #message{from = JID, subject = Subject, body = Body} = Msg ->
+            Msg2 = case {xmpp:get_text(Subject), xmpp:get_text(Body)} of
+                       {_, <<>>} -> Msg;
+                       {<<>>, _} -> Msg#message{subject = []};
+                       _ -> Msg
+                   end,
             State = #{jid => JID},
-            ejabberd_hooks:run_fold(user_send_packet, JID#jid.lserver, {Msg, State}, []),
-            ejabberd_router:route(Msg)
+            ejabberd_hooks:run_fold(user_send_packet, JID#jid.lserver, {Msg2, State}, []),
+            ejabberd_router:route(Msg2)
     catch _:{xmpp_codec, Why} ->
             {error, xmpp:format_error(Why)}
     end.
@@ -1509,7 +1514,11 @@ send_stanza(FromString, ToString, Stanza) ->
 	To = jid:decode(ToString),
 	CodecOpts = ejabberd_config:codec_options(),
 	Pkt = xmpp:decode(El, ?NS_CLIENT, CodecOpts),
-	ejabberd_router:route(xmpp:set_from_to(Pkt, From, To))
+        Pkt2 = xmpp:set_from_to(Pkt, From, To),
+        State = #{jid => From},
+        ejabberd_hooks:run_fold(user_send_packet, From#jid.lserver,
+                                {Pkt2, State}, []),
+        ejabberd_router:route(Pkt2)
     catch _:{xmpp_codec, Why} ->
 	    io:format("incorrect stanza: ~ts~n", [xmpp:format_error(Why)]),
 	    {error, Why};
