@@ -5,7 +5,7 @@
 %%% Created :  9 Aug 2017 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -37,7 +37,7 @@
 
 -include("logger.hrl").
 -include("ejabberd_commands.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("ejabberd_sql_pt.hrl").
 -include("translate.hrl").
 
@@ -363,5 +363,6 @@ mod_options(_) -> [].
 mod_doc() ->
     #{desc =>
           ?T("This module can be used to update existing SQL database "
-             "from 'old' to 'new' schema. When the module is loaded "
-             "use 'update_sql' ejabberdctl command.")}.
+             "from the default to the new schema. Check the section "
+             "http://../database-ldap/#default-and-new-schemas[Default and New Schemas] for details. "
+             "When the module is loaded use 'update_sql' ejabberdctl command.")}.
