@@ -5,7 +5,7 @@
 %%% Created : 15 Oct 2015 by Holger Weiss <holger@zedat.fu-berlin.de>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2015-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2015-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -52,7 +52,7 @@
 %% ejabberd_hooks callback.
 -export([handle_slot_request/6]).
 
--include("jid.hrl").
+-include_lib("xmpp/include/jid.hrl").
 -include("logger.hrl").
 -include("translate.hrl").
 -include_lib("kernel/include/file.hrl").
