@@ -4,7 +4,7 @@
 %%% Created : 15 Apr 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -33,7 +33,7 @@
 	 is_empty_for_user/2, is_empty_for_room/3, select_with_mucsub/6]).
 
 -include_lib("stdlib/include/ms_transform.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("mod_mam.hrl").
 -include("logger.hrl").
 -include("ejabberd_sql_pt.hrl").
@@ -221,7 +221,7 @@ select_with_mucsub(LServer, JidRequestor, #jid{luser = LUser} = JidArchive,
 				   _ ->
 				       []
 			       end,
-		    [jid:encode(Jid) || {Jid, _} <- SubRooms]
+		    [jid:encode(Jid) || {Jid, _, _} <- SubRooms]
 	    end,
     {Query, CountQuery} = make_sql_query(LUser, LServer, MAMQuery, RSM, Extra),
     do_select_query(LServer, JidRequestor, JidArchive, RSM, chat, Query, CountQuery, Flags).
@@ -256,7 +256,7 @@ do_select_query(LServer, JidRequestor, #jid{luser = LUser} = JidArchive, RSM,
 		    {Res, true}
 	    end,
 	    MucState = #state{config = #config{anonymous = true}},
-	    JidArchiveS = jid:encode(JidArchive),
+	    JidArchiveS = jid:encode(jid:remove_resource(JidArchive)),
 	    {lists:flatmap(
 		fun([TS, XML, PeerBin, Kind, Nick]) ->
 		    case make_archive_el(JidArchiveS, TS, XML, PeerBin, Kind, Nick,
