@@ -5,7 +5,7 @@
 %%% Created : 8 Sep 2007 by Badlop <badlop@ono.com>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -44,7 +44,7 @@
 	 web_page_host/3, mod_options/1, get_commands_spec/0, find_hosts/1]).
 
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("mod_muc.hrl").
 -include("mod_muc_room.hrl").
 -include("ejabberd_http.hrl").
@@ -264,7 +264,11 @@ get_commands_spec() ->
 
      #ejabberd_commands{name = send_direct_invitation, tags = [muc_room],
 			desc = "Send a direct invitation to several destinations",
-			longdesc = "Password and Message can also be: none. Users JIDs are separated with : ",
+			longdesc = "Since ejabberd 20.10, this command is "
+                        "asynchronous: the API call may return before the "
+                        "server has send all the invitations.\n\n"
+                        "Password and Message can also be: none. "
+                        "Users JIDs are separated with : ",
 			module = ?MODULE, function = send_direct_invitation,
 		        args_desc = ["Room name", "MUC service", "Password, or none",
 			 "Reason text, or none", "Users JIDs separated with : characters"],
@@ -401,12 +405,25 @@ build_summary_room(Name, Host, Pid) ->
     }.
 
 muc_register_nick(Nick, FromBinary, Service) ->
-    ServerHost = get_room_serverhost(Service),
-    From = jid:decode(FromBinary),
-    Lang = <<"en">>,
-    case mod_muc:iq_set_register_info(ServerHost, Service, From, Nick, Lang) of
-	{result, undefined} -> ok;
-	E -> E
+    try {get_room_serverhost(Service), jid:decode(FromBinary)} of
+	{ServerHost, From} ->
+	    Lang = <<"en">>,
+	    case mod_muc:iq_set_register_info(ServerHost, Service, From, Nick, Lang) of
+		{result, undefined} -> ok;
+		{error, #stanza_error{reason = 'conflict'}} ->
+		    throw({error, "Nick already registered"});
+		{error, _} ->
+		    throw({error, "Database error"})
+	    end
+	catch
+	error:{invalid_domain, _} ->
+	    throw({error, "Invalid 'service'"});
+	error:{unregistered_route, _} ->
+	    throw({error, "Invalid 'service'"});
+	error:{bad_jid, _} ->
+	    throw({error, "Invalid 'jid'"});
+	_ ->
+	    throw({error, "Internal error"})
     end.
 
 muc_unregister_nick(FromBinary, Service) ->
@@ -503,7 +520,7 @@ get_sort_query2(Q) ->
 
 make_rooms_page(Host, Lang, {Sort_direction, Sort_column}) ->
     Service = find_service(Host),
-    Rooms_names = get_rooms(Service),
+    Rooms_names = get_online_rooms(Service),
     Rooms_infos = build_info_rooms(Rooms_names),
     Rooms_sorted = sort_rooms(Sort_direction, Sort_column, Rooms_infos),
     Rooms_prepared = prepare_rooms_infos(Rooms_sorted),
@@ -628,53 +645,58 @@ create_room(Name1, Host1, ServerHost) ->
     create_room_with_opts(Name1, Host1, ServerHost, []).
 
 create_room_with_opts(Name1, Host1, ServerHost1, CustomRoomOpts) ->
-    true = (error /= (Name = jid:nodeprep(Name1))),
-    true = (error /= (Host = jid:nodeprep(Host1))),
-    true = (error /= (ServerHost = jid:nodeprep(ServerHost1))),
+    case {jid:nodeprep(Name1), jid:nodeprep(Host1), jid:nodeprep(ServerHost1)} of
+	{error, _, _} ->
+	    throw({error, "Invalid 'name'"});
+	{_, error, _} ->
+	    throw({error, "Invalid 'host'"});
+	{_, _, error} ->
+	    throw({error, "Invalid 'serverhost'"});
+	{Name, Host, ServerHost} ->
+	    %% Get the default room options from the muc configuration
+	    DefRoomOpts = mod_muc_opt:default_room_options(ServerHost),
+	    %% Change default room options as required
+	    FormattedRoomOpts = [format_room_option(Opt, Val) || {Opt, Val}<-CustomRoomOpts],
+	    RoomOpts = lists:ukeymerge(1,
+				       lists:keysort(1, FormattedRoomOpts),
+				       lists:keysort(1, DefRoomOpts)),
 
-    %% Get the default room options from the muc configuration
-    DefRoomOpts = mod_muc_opt:default_room_options(ServerHost),
-    %% Change default room options as required
-    FormattedRoomOpts = [format_room_option(Opt, Val) || {Opt, Val}<-CustomRoomOpts],
-    RoomOpts = lists:ukeymerge(1,
-                               lists:keysort(1, FormattedRoomOpts),
-                               lists:keysort(1, DefRoomOpts)),
 
-    %% Store the room on the server, it is not started yet though at this point
-    case lists:keyfind(persistent, 1, RoomOpts) of
-	{persistent, true} ->
-	    mod_muc:store_room(ServerHost, Host, Name, RoomOpts);
-	_ ->
-	    ok
-    end,
+	    %% Get all remaining mod_muc parameters that might be utilized
+	    Access = mod_muc_opt:access(ServerHost),
+	    AcCreate = mod_muc_opt:access_create(ServerHost),
+	    AcAdmin = mod_muc_opt:access_admin(ServerHost),
+	    AcPer = mod_muc_opt:access_persistent(ServerHost),
+	    AcMam = mod_muc_opt:access_mam(ServerHost),
+	    HistorySize = mod_muc_opt:history_size(ServerHost),
+	    RoomShaper = mod_muc_opt:room_shaper(ServerHost),
+	    QueueType = mod_muc_opt:queue_type(ServerHost),
 
-    %% Get all remaining mod_muc parameters that might be utilized
-    Access = mod_muc_opt:access(ServerHost),
-    AcCreate = mod_muc_opt:access_create(ServerHost),
-    AcAdmin = mod_muc_opt:access_admin(ServerHost),
-    AcPer = mod_muc_opt:access_persistent(ServerHost),
-    AcMam = mod_muc_opt:access_mam(ServerHost),
-    HistorySize = mod_muc_opt:history_size(ServerHost),
-    RoomShaper = mod_muc_opt:room_shaper(ServerHost),
-    QueueType = mod_muc_opt:queue_type(ServerHost),
-
-    %% If the room does not exist yet in the muc_online_room
-    case mod_muc:find_online_room(Name, Host) of
-	error ->
-	    %% Start the room
-	    {ok, Pid} = mod_muc_room:start(
-			  Host,
-			  ServerHost,
-			  {Access, AcCreate, AcAdmin, AcPer, AcMam},
-			  Name,
-			  HistorySize,
-			  RoomShaper,
-			  RoomOpts,
-			  QueueType),
-	    mod_muc:register_online_room(Name, Host, Pid),
-	    ok;
-	{ok, _} ->
-	    error
+	    %% If the room does not exist yet in the muc_online_room
+	    case get_room_pid(Name, Host) of
+		room_not_found ->
+		    %% Store the room on the server, it is not started yet though at this point
+		    case lists:keyfind(persistent, 1, RoomOpts) of
+			{persistent, true} ->
+			    mod_muc:store_room(ServerHost, Host, Name, RoomOpts);
+			_ ->
+			    ok
+		    end,
+		    %% Start the room
+		    {ok, Pid} = mod_muc_room:start(
+			Host,
+			ServerHost,
+			{Access, AcCreate, AcAdmin, AcPer, AcMam},
+			Name,
+			HistorySize,
+			RoomShaper,
+			RoomOpts,
+			QueueType),
+		    mod_muc:register_online_room(Name, Host, Pid),
+		    ok;
+		_ ->
+		    throw({error, "Room already exists"})
+	    end
     end.
 
 %% Create the room only in the database.
@@ -688,12 +710,22 @@ muc_create_room(ServerHost, {Name, Host, _}, DefRoomOpts) ->
 %% @doc Destroy the room immediately.
 %% If the room has participants, they are not notified that the room was destroyed;
 %% they will notice when they try to chat and receive an error that the room doesn't exist.
-destroy_room(Name, Service) ->
-    case mod_muc:find_online_room(Name, Service) of
-	{ok, Pid} ->
-	    mod_muc_room:destroy(Pid);
-	error ->
-	    error
+destroy_room(Name1, Service1) ->
+    case {jid:nodeprep(Name1), jid:nodeprep(Service1)} of
+	{error, _} ->
+	    throw({error, "Invalid 'name'"});
+	{_, error} ->
+	    throw({error, "Invalid 'service'"});
+	{Name, Service} ->
+	    case get_room_pid(Name, Service) of
+		room_not_found ->
+		    throw({error, "Room doesn't exists"});
+		invalid_service ->
+		    throw({error, "Invalid 'service'"});
+		Pid ->
+		    mod_muc_room:destroy(Pid),
+		    ok
+	    end
     end.
 
 destroy_room({N, H, SH}) ->
@@ -714,7 +746,7 @@ destroy_rooms_file(Filename) ->
     Rooms = read_rooms(F, RJID, []),
     file:close(F),
     [destroy_room(A) || A <- Rooms],
-	ok.
+    ok.
 
 read_rooms(_F, eof, L) ->
     L;
@@ -758,7 +790,7 @@ create_rooms_file(Filename) ->
     %% Read the default room options defined for the first virtual host
     DefRoomOpts = mod_muc_opt:default_room_options(ejabberd_config:get_myname()),
     [muc_create_room(ejabberd_config:get_myname(), A, DefRoomOpts) || A <- Rooms],
-	ok.
+    ok.
 
 
 %%---------------------------------
@@ -786,7 +818,7 @@ rooms_report(Method, Action, Service, Days) ->
 
 muc_unused(Method, Action, Service, Last_allowed) ->
     %% Get all required info about all existing rooms
-    Rooms_all = get_rooms(Service),
+    Rooms_all = get_all_rooms(Service),
 
     %% Decide which ones pass the requirements
     Rooms_pass = decide_rooms(Method, Rooms_all, Last_allowed),
@@ -802,14 +834,42 @@ muc_unused(Method, Action, Service, Last_allowed) ->
 %%---------------
 %% Get info
 
-get_rooms(ServiceArg) ->
+get_online_rooms(ServiceArg) ->
     Hosts = find_services(ServiceArg),
     lists:flatmap(
       fun(Host) ->
-	      [{RoomName, RoomHost, ejabberd_router:host_of_route(Host), Pid}
-	       || {RoomName, RoomHost, Pid} <- mod_muc:get_online_rooms(Host)]
+	  ServerHost = get_room_serverhost(Host),
+	  [{RoomName, RoomHost, ServerHost, Pid}
+	   || {RoomName, RoomHost, Pid} <- mod_muc:get_online_rooms(Host)]
       end, Hosts).
 
+get_all_rooms(Host) ->
+    ServerHost = ejabberd_router:host_of_route(Host),
+    OnlineRooms = get_online_rooms(Host),
+    OnlineMap = lists:foldl(
+	fun({Room, _, _, _}, Map) ->
+	    Map#{Room => 1}
+	end, #{}, OnlineRooms),
+
+    Mod = gen_mod:db_mod(ServerHost, mod_muc),
+    DbRooms =
+    case erlang:function_exported(Mod, get_rooms_without_subscribers, 2) of
+	true ->
+	    Mod:get_rooms_without_subscribers(ServerHost, Host);
+	_ ->
+	    Mod:get_rooms(ServerHost, Host)
+    end,
+    StoredRooms = lists:filtermap(
+	fun(#muc_room{name_host = {Room, _}, opts = Opts}) ->
+	    case maps:is_key(Room, OnlineMap) of
+		true ->
+		    false;
+		_ ->
+		    {true, {Room, Host, ServerHost, Opts}}
+	    end
+	end, DbRooms),
+    OnlineRooms ++ StoredRooms.
+
 get_room_config(Room_pid) ->
     {ok, R} = mod_muc_room:get_config(Room_pid),
     R.
@@ -826,45 +886,55 @@ decide_rooms(Method, Rooms, Last_allowed) ->
     lists:filter(Decide, Rooms).
 
 decide_room(unused, {_Room_name, _Host, ServerHost, Room_pid}, Last_allowed) ->
-    C = get_room_config(Room_pid),
-    Persistent = C#config.persistent,
-
-    S = get_room_state(Room_pid),
-    Just_created = S#state.just_created,
-
-    Room_users = S#state.users,
-    Num_users = maps:size(Room_users),
-
-    History = (S#state.history)#lqueue.queue,
-    Ts_now = calendar:universal_time(),
-    HistorySize = mod_muc_opt:history_size(ServerHost),
-    {Has_hist, Last} = case p1_queue:is_empty(History) of
-			   true when (HistorySize == 0) or (Just_created == true) ->
-			       {false, 0};
-			   true ->
-			       Ts_diff = (erlang:system_time(microsecond)
-				    - Just_created) div 1000000,
-			       {false, Ts_diff};
-			   false ->
-			       Last_message = get_queue_last(History),
-			       Ts_last = calendar:now_to_universal_time(
-					   element(4, Last_message)),
-			       Ts_diff =
-				   calendar:datetime_to_gregorian_seconds(Ts_now)
-				   - calendar:datetime_to_gregorian_seconds(Ts_last),
-			       {true, Ts_diff}
-		       end,
-    case {Persistent, Just_created, Num_users, Has_hist, seconds_to_days(Last)} of
-	{_true, JC, 0, _, Last_days}
-	when (Last_days >= Last_allowed) and (JC /= true) ->
+    NodeStartTime = erlang:system_time(microsecond) -
+		    1000000*(erlang:monotonic_time(second)-ejabberd_config:get_node_start()),
+    OnlyHibernated = case mod_muc_opt:hibernation_timeout(ServerHost) of
+	Value when Value < Last_allowed*24*60*60*1000 ->
+	    true;
+	_ ->
+	    false
+	end,
+    {Just_created, Num_users} =
+    case Room_pid of
+	Pid when is_pid(Pid) andalso OnlyHibernated ->
+	    {erlang:system_time(microsecond), 0};
+	Pid when is_pid(Pid) ->
+	    case mod_muc_room:get_state(Room_pid) of
+		{ok, #state{just_created = JC, users = U}} ->
+		    {JC, maps:size(U)};
+		_ ->
+		    {erlang:system_time(microsecond), 0}
+	    end;
+	Opts ->
+	    case lists:keyfind(hibernation_time, 1, Opts) of
+		false ->
+		    {NodeStartTime, 0};
+		{_, T} ->
+		    {T, 0}
+	    end
+    end,
+    Last = case Just_created of
+	       true ->
+		   0;
+	       _ ->
+		   (erlang:system_time(microsecond)
+		    - Just_created) div 1000000
+	   end,
+    case {Num_users, seconds_to_days(Last)} of
+	{0, Last_days} when (Last_days >= Last_allowed) ->
 	    true;
 	_ ->
 	    false
     end;
-decide_room(empty, {Room_name, Host, ServerHost, _Room_pid}, _Last_allowed) ->
+decide_room(empty, {Room_name, Host, ServerHost, Room_pid}, _Last_allowed) ->
     case gen_mod:is_loaded(ServerHost, mod_mam) of
 	true ->
-	    Room_options = get_room_options(Room_name, Host),
+	    Room_options = case Room_pid of
+			       _ when is_pid(Room_pid) ->
+				   get_room_options(Room_pid);
+			       Opts ->
+				   Opts
+			   end,
 	    case lists:keyfind(<<"mam">>, 1, Room_options) of
 		{<<"mam">>, <<"true">>} ->
 		    mod_mam:is_empty_for_room(ServerHost, Room_name, Host);
@@ -887,13 +957,20 @@ act_on_rooms(Method, Action, Rooms) ->
 	     end,
     lists:foreach(Delete, Rooms).
 
-act_on_room(Method, destroy, {N, H, SH, Pid}) ->
+act_on_room(Method, destroy, {N, H, _SH, Pid}) ->
     Message = iolist_to_binary(io_lib:format(
         <<"Room destroyed by rooms_~s_destroy.">>, [Method])),
-    mod_muc_room:destroy(Pid, Message),
-    mod_muc:room_destroyed(H, N, Pid, SH),
-    mod_muc:forget_room(SH, H, N);
-
+    case Pid of
+	V when is_pid(V) ->
+	    mod_muc_room:destroy(Pid, Message);
+	_ ->
+	    case get_room_pid(N, H) of
+		Pid2 when is_pid(Pid2) ->
+		    mod_muc_room:destroy(Pid2, Message);
+		_ ->
+		    ok
+	    end
+    end;
 act_on_room(_Method, list, _) ->
     ok.
 
@@ -904,8 +981,8 @@ act_on_room(_Method, list, _) ->
 
 get_room_occupants(Room, Host) ->
     case get_room_pid(Room, Host) of
-	room_not_found -> throw({error, room_not_found});
-	Pid -> get_room_occupants(Pid)
+	Pid when is_pid(Pid) -> get_room_occupants(Pid);
+	_ -> throw({error, room_not_found})
     end.
 
 get_room_occupants(Pid) ->
@@ -920,11 +997,11 @@ get_room_occupants(Pid) ->
 
 get_room_occupants_number(Room, Host) ->
     case get_room_pid(Room, Host) of
-	room_not_found ->
-	    throw({error, room_not_found});
-	Pid ->
+	Pid when is_pid(Pid )->
 	    S = get_room_state(Pid),
-	    maps:size(S#state.users)
+	    maps:size(S#state.users);
+	_ ->
+	    throw({error, room_not_found})
     end.
 
 %%----------------------------
@@ -933,13 +1010,16 @@ get_room_occupants_number(Room, Host) ->
 %% http://xmpp.org/extensions/xep-0249.html
 
 send_direct_invitation(RoomName, RoomService, Password, Reason, UsersString) ->
-    RoomJid = jid:make(RoomName, RoomService),
-    XmlEl = build_invitation(Password, Reason, RoomJid),
-    Users = get_users_to_invite(RoomJid, UsersString),
-    [send_direct_invitation(RoomJid, UserJid, XmlEl)
-     || UserJid <- Users],
-    timer:sleep(1000),
-    ok.
+    case jid:make(RoomName, RoomService) of
+	error ->
+	    throw({error, "Invalid 'roomname' or 'service'"});
+	RoomJid ->
+	    XmlEl = build_invitation(Password, Reason, RoomJid),
+	    Users = get_users_to_invite(RoomJid, UsersString),
+	    [send_direct_invitation(RoomJid, UserJid, XmlEl)
+	     || UserJid <- Users],
+	    ok
+    end.
 
 get_users_to_invite(RoomJid, UsersString) ->
     UsersStrings = binary:split(UsersString, <<":">>, [global]),
@@ -993,7 +1073,9 @@ send_direct_invitation(FromJid, UserJid, Msg) ->
 change_room_option(Name, Service, OptionString, ValueString) ->
     case get_room_pid(Name, Service) of
 	room_not_found ->
-	    room_not_found;
+	    throw({error, "Room not found"});
+	invalid_service ->
+	    throw({error, "Invalid 'service'"});
 	Pid ->
 	    {Option, Value} = format_room_option(OptionString, ValueString),
 	    change_room_option(Pid, Option, Value)
@@ -1033,12 +1115,21 @@ format_room_option(OptionString, ValueString) ->
     {Option, Value}.
 
 %% @doc Get the Pid of an existing MUC room, or 'room_not_found'.
+-spec get_room_pid(binary(), binary()) -> pid() | room_not_found | invalid_service.
 get_room_pid(Name, Service) ->
-    case mod_muc:find_online_room(Name, Service) of
-	error ->
-	    room_not_found;
-	{ok, Pid} ->
-	    Pid
+    try get_room_serverhost(Service) of
+	ServerHost ->
+	    case mod_muc:unhibernate_room(ServerHost, Service, Name) of
+		error ->
+		    room_not_found;
+		{ok, Pid} ->
+		    Pid
+	    end
+    catch
+	error:{invalid_domain, _} ->
+	    invalid_service;
+	error:{unregistered_route, _} ->
+	    invalid_service
     end.
 
 %% It is required to put explicitly all the options because
@@ -1081,8 +1172,8 @@ change_option(Option, Value, Config) ->
 
 get_room_options(Name, Service) ->
     case get_room_pid(Name, Service) of
-        room_not_found -> [];
-        Pid -> get_room_options(Pid)
+        Pid when is_pid(Pid) -> get_room_options(Pid);
+	_ -> []
     end.
 
 get_room_options(Pid) ->
@@ -1106,8 +1197,8 @@ get_options(Config) ->
 %%    [{JID::string(), Domain::string(), Role::string(), Reason::string()}]
 %% @doc Get the affiliations of  the room Name@Service.
 get_room_affiliations(Name, Service) ->
-    case mod_muc:find_online_room(Name, Service) of
-	{ok, Pid} ->
+    case get_room_pid(Name, Service) of
+	Pid when is_pid(Pid) ->
 	    %% Get the PID of the online room, then request its state
 	    {ok, StateData} = mod_muc_room:get_state(Pid),
 	    Affiliations = maps:to_list(StateData#state.affiliations),
@@ -1117,7 +1208,7 @@ get_room_affiliations(Name, Service) ->
 		 ({{Uname, Domain, _Res}, Aff}) when is_atom(Aff)->
 		      {Uname, Domain, Aff, <<>>}
 	      end, Affiliations);
-	error ->
+	_ ->
 	    throw({error, "The room does not exist."})
     end.
 
@@ -1130,13 +1221,13 @@ get_room_affiliations(Name, Service) ->
 %% @doc Get affiliation of a user in the room Name@Service.
 
 get_room_affiliation(Name, Service, JID) ->
-	case mod_muc:find_online_room(Name, Service) of
-	{ok, Pid} ->
+	case get_room_pid(Name, Service) of
+	    Pid when is_pid(Pid) ->
 		%% Get the PID of the online room, then request its state
 		{ok, StateData} = mod_muc_room:get_state(Pid),
 		UserJID = jid:decode(JID),
 		mod_muc_room:get_affiliation(UserJID, StateData);
-	error ->
+	    _ ->
 		throw({error, "The room does not exist."})
 	end.
 
@@ -1153,15 +1244,30 @@ get_room_affiliation(Name, Service, JID) ->
 %% If the affiliation is 'none', the action is to remove,
 %% In any other case the action will be to create the affiliation.
 set_room_affiliation(Name, Service, JID, AffiliationString) ->
-    Affiliation = misc:binary_to_atom(AffiliationString),
-    case mod_muc:find_online_room(Name, Service) of
-	{ok, Pid} ->
+    Affiliation = case AffiliationString of
+                      <<"outcast">> -> outcast;
+                      <<"none">> -> none;
+                      <<"member">> -> member;
+                      <<"admin">> -> admin;
+                      <<"owner">> -> owner;
+                      _ ->
+                          throw({error, "Invalid affiliation"})
+                  end,
+    case get_room_pid(Name, Service) of
+	Pid when is_pid(Pid) ->
 	    %% Get the PID for the online room so we can get the state of the room
-	    {ok, StateData} = mod_muc_room:change_item(Pid, jid:decode(JID), affiliation, Affiliation, <<"">>),
-	    mod_muc:store_room(StateData#state.server_host, StateData#state.host, StateData#state.room, make_opts(StateData)),
-	    ok;
-	error ->
-	    error
+	    case mod_muc_room:change_item(Pid, jid:decode(JID), affiliation, Affiliation, <<"">>) of
+		{ok, _} ->
+		    ok;
+		{error, notfound} ->
+		    throw({error, "Room doesn't exists"});
+		{error, _} ->
+		    throw({error, "Unable to perform change"})
+	    end;
+	room_not_found ->
+	    throw({error, "Room doesn't exists"});
+	invalid_service ->
+	    throw({error, "Invalid 'service'"})
     end.
 
 %%%
@@ -1232,52 +1338,6 @@ get_subscribers(Name, Host) ->
 	    throw({error, "The room does not exist"})
     end.
 
-%% Copied from mod_muc_room.erl
-get_config_opt_name(Pos) ->
-    Fs = [config|record_info(fields, config)],
-    lists:nth(Pos, Fs).
--define(MAKE_CONFIG_OPT(Opt),
-        {get_config_opt_name(Opt), element(Opt, Config)}).
-make_opts(StateData) ->
-    Config = StateData#state.config,
-    Subscribers = maps:fold(
-                    fun(_LJID, Sub, Acc) ->
-                            [{Sub#subscriber.jid,
-                              Sub#subscriber.nick,
-                              Sub#subscriber.nodes}|Acc]
-                    end, [], StateData#state.subscribers),
-    [?MAKE_CONFIG_OPT(#config.title), ?MAKE_CONFIG_OPT(#config.description),
-     ?MAKE_CONFIG_OPT(#config.allow_change_subj),
-     ?MAKE_CONFIG_OPT(#config.allow_query_users),
-     ?MAKE_CONFIG_OPT(#config.allow_private_messages),
-     ?MAKE_CONFIG_OPT(#config.allow_private_messages_from_visitors),
-     ?MAKE_CONFIG_OPT(#config.allow_visitor_status),
-     ?MAKE_CONFIG_OPT(#config.allow_visitor_nickchange),
-     ?MAKE_CONFIG_OPT(#config.public), ?MAKE_CONFIG_OPT(#config.public_list),
-     ?MAKE_CONFIG_OPT(#config.persistent),
-     ?MAKE_CONFIG_OPT(#config.moderated),
-     ?MAKE_CONFIG_OPT(#config.members_by_default),
-     ?MAKE_CONFIG_OPT(#config.members_only),
-     ?MAKE_CONFIG_OPT(#config.allow_user_invites),
-     ?MAKE_CONFIG_OPT(#config.password_protected),
-     ?MAKE_CONFIG_OPT(#config.captcha_protected),
-     ?MAKE_CONFIG_OPT(#config.password), ?MAKE_CONFIG_OPT(#config.anonymous),
-     ?MAKE_CONFIG_OPT(#config.logging), ?MAKE_CONFIG_OPT(#config.max_users),
-     ?MAKE_CONFIG_OPT(#config.allow_voice_requests),
-     ?MAKE_CONFIG_OPT(#config.allow_subscription),
-     ?MAKE_CONFIG_OPT(#config.mam),
-     ?MAKE_CONFIG_OPT(#config.presence_broadcast),
-     ?MAKE_CONFIG_OPT(#config.voice_request_min_interval),
-     ?MAKE_CONFIG_OPT(#config.vcard),
-     {captcha_whitelist,
-      (?SETS):to_list((StateData#state.config)#config.captcha_whitelist)},
-     {affiliations,
-      maps:to_list(StateData#state.affiliations)},
-     {subject, StateData#state.subject},
-     {subject_author, StateData#state.subject_author},
-     {subscribers, Subscribers}].
-
-
 %%----------------------------
 %% Utils
 %%----------------------------
