@@ -4,7 +4,7 @@
 %%% Created : 13 Apr 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -36,11 +36,11 @@
 	 get_online_rooms/3, count_online_rooms/2, rsm_supported/0,
 	 register_online_user/4, unregister_online_user/4,
 	 count_online_rooms_by_user/3, get_online_rooms_by_user/3,
-	 get_subscribed_rooms/3]).
+	 get_subscribed_rooms/3, get_rooms_without_subscribers/2]).
 -export([set_affiliation/6, set_affiliations/4, get_affiliation/5,
 	 get_affiliations/3, search_affiliation/4]).
 
--include("jid.hrl").
+-include_lib("xmpp/include/jid.hrl").
 -include("mod_muc.hrl").
 -include("logger.hrl").
 -include("ejabberd_sql_pt.hrl").
@@ -155,6 +155,22 @@ can_use_nick(LServer, Host, JID, Nick) ->
 	_ -> true
     end.
 
+get_rooms_without_subscribers(LServer, Host) ->
+    case catch ejabberd_sql:sql_query(
+	LServer,
+	?SQL("select @(name)s, @(opts)s from muc_room"
+	     " where host=%(Host)s")) of
+	{selected, RoomOpts} ->
+	    lists:map(
+		fun({Room, Opts}) ->
+		    OptsD = ejabberd_sql:decode_term(Opts),
+		    #muc_room{name_host = {Room, Host},
+			      opts = mod_muc:opts_to_binary(OptsD)}
+		end, RoomOpts);
+	_Err ->
+	    []
+    end.
+
 get_rooms(LServer, Host) ->
     case catch ejabberd_sql:sql_query(
                  LServer,
@@ -410,11 +426,11 @@ get_subscribed_rooms(LServer, Host, Jid) ->
     JidS = jid:encode(Jid),
     case ejabberd_sql:sql_query(
 	   LServer,
-	   ?SQL("select @(room)s, @(nodes)s from muc_room_subscribers "
+	   ?SQL("select @(room)s, @(nick)s, @(nodes)s from muc_room_subscribers "
 		"where jid=%(JidS)s and host=%(Host)s")) of
 	{selected, Subs} ->
-	    {ok, [{jid:make(Room, Host), ejabberd_sql:decode_term(Nodes)}
-		  || {Room, Nodes} <- Subs]};
+	    {ok, [{jid:make(Room, Host), Nick, ejabberd_sql:decode_term(Nodes)}
+		  || {Room, Nick, Nodes} <- Subs]};
 	_Error ->
 	    {error, db_failure}
     end.
