@@ -5,7 +5,7 @@
 %%% Created :  5 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -69,7 +69,7 @@
 
 -include("logger.hrl").
 
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 
 -include("ejabberd_http.hrl").
 
@@ -988,7 +988,7 @@ user_queue(User, Server, Query, Lang) ->
 	      end,
     Hdrs = get_messages_subset(User, Server, HdrsAll),
     FMsgs = format_user_queue(Hdrs),
-    PageTitle = str:format(translate:translate(Lang, ?T("~ts's Offline Messages Queue")), [us_to_list(US)]),
+    PageTitle = str:translate_and_format(Lang, ?T("~ts's Offline Messages Queue"), [us_to_list(US)]),
     (?H1GL(PageTitle, <<"modules/#mod-offline">>, <<"mod_offline">>))
       ++ [?XREST(?T("Submitted"))] ++
 	[?XAE(<<"form">>,
@@ -1008,7 +1008,7 @@ user_queue(User, Server, Query, Lang) ->
 			   true -> FMsgs
 			end)]),
 	       ?BR,
-	       ?INPUTT(<<"submit">>, <<"delete">>,
+	       ?INPUTTD(<<"submit">>, <<"delete">>,
 		       ?T("Delete Selected"))])].
 
 user_queue_parse_query(LUser, LServer, Query) ->
@@ -1070,14 +1070,17 @@ get_messages_subset2(Max, Length, MsgsAll) ->
 webadmin_user(Acc, User, Server, Lang) ->
     QueueLen = count_offline_messages(jid:nodeprep(User),
 				jid:nameprep(Server)),
-    FQueueLen = [?AC(<<"queue/">>,
-		     (integer_to_binary(QueueLen)))],
+    FQueueLen = ?C(integer_to_binary(QueueLen)),
+    FQueueView = ?AC(<<"queue/">>,
+		     ?T("View Queue")),
     Acc ++
-      [?XCT(<<"h3">>, ?T("Offline Messages:"))] ++
-	FQueueLen ++
-	  [?C(<<" ">>),
-	   ?INPUTT(<<"submit">>, <<"removealloffline">>,
-		   ?T("Remove All Offline Messages"))].
+        [?XCT(<<"h3">>, ?T("Offline Messages:")),
+         FQueueLen,
+         ?C(<<"  |   ">>),
+         FQueueView,
+         ?C(<<" | ">>),
+         ?INPUTTD(<<"submit">>, <<"removealloffline">>,
+                  ?T("Remove All Offline Messages"))].
 
 -spec delete_all_msgs(binary(), binary()) -> {atomic, any()}.
 delete_all_msgs(User, Server) ->
