@@ -4,7 +4,7 @@
 %%% Created : 15 Apr 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -32,7 +32,7 @@
 	 read_message/3, remove_message/3, read_all_messages/2,
 	 remove_all_messages/2, count_messages/2, import/1, export/1]).
 
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("mod_offline.hrl").
 -include("logger.hrl").
 -include("ejabberd_sql_pt.hrl").
@@ -94,6 +94,11 @@ remove_old_messages(Days, LServer) ->
                      ?SQL("DELETE FROM spool"
                           " WHERE created_at <"
                           " NOW() - %(Days)d * INTERVAL '1 DAY'"));
+	      (sqlite, _) ->
+		  ejabberd_sql:sql_query_t(
+		      ?SQL("DELETE FROM spool"
+			   " WHERE created_at <"
+			   " DATETIME('now', '-%(Days)d days')"));
               (_, _) ->
                    ejabberd_sql:sql_query_t(
                      ?SQL("DELETE FROM spool"
