@@ -5,7 +5,7 @@
 %%% Created : 15 Jul 2017 by Holger Weiss <holger@zedat.fu-berlin.de>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2017-2020 ProcessOne
+%%% ejabberd, Copyright (C) 2017-2021 ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -51,7 +51,7 @@
 
 -include("ejabberd_commands.hrl").
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("translate.hrl").
 
 -define(PUSH_CACHE, push_cache).
@@ -119,7 +119,9 @@ reload(Host, NewOpts, OldOpts) ->
 	    NewMod:init(Host, NewOpts);
        true ->
 	    ok
-    end.
+    end,
+    init_cache(NewMod, Host, NewOpts),
+    ok.
 
 -spec depends(binary(), gen_mod:opts()) -> [{module(), hard | soft}].
 depends(_Host, _Opts) ->
@@ -241,9 +243,9 @@ delete_old_sessions(Days) ->
 	[] ->
 	    ?INFO_MSG("Deleted push sessions older than ~B days", [Days]),
 	    ok;
-	[NotOk | _] ->
-	    ?ERROR_MSG("Error while deleting old push sessions: ~p", [NotOk]),
-	    NotOk
+	[{error, Reason} | _] ->
+	    ?ERROR_MSG("Error while deleting old push sessions: ~p", [Reason]),
+	    Reason
     end.
 
 %%--------------------------------------------------------------------
