@@ -5,7 +5,7 @@
 %%% Created :  8 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -38,7 +38,7 @@
 	 format_error/1, mod_doc/0]).
 
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("translate.hrl").
 
 start(Host, _Opts) ->
@@ -114,13 +114,12 @@ process_iq(#iq{from = From, to = To} = IQ, Source) ->
 	end,
     Server = To#jid.lserver,
     Access = mod_register_opt:access_remove(Server),
-    Remove = case acl:match_rule(Server, Access, From) of
-                 deny -> deny;
-                 allow when From#jid.lserver /= Server ->
-                     deny;
-                 allow ->
-                     check_access(From#jid.luser, Server, Source)
-             end,
+    Remove = case {acl:match_rule(Server, Access, From), From#jid.lserver} of
+		 {allow, Server} ->
+		     allow;
+		 {_, _} ->
+		     deny
+	     end,
     process_iq(IQ, Source, IsCaptchaEnabled, Remove == allow).
 
 process_iq(#iq{type = set, lang = Lang,
@@ -223,8 +222,7 @@ process_iq(#iq{type = get, from = From, to = To, id = ID, lang = Lang} = IQ,
 		       "with this server")),
     URL = mod_register_opt:redirect_url(Server),
     if (URL /= undefined) and not IsRegistered ->
-	    Txt = translate:translate(Lang, ?T("To register, visit ~s")),
-	    Desc = str:format(Txt, [URL]),
+	    Desc = str:translate_and_format(Lang, ?T("To register, visit ~s"), [URL]),
 	    xmpp:make_iq_result(
 	      IQ, #register{instructions = Desc,
 			    sub_els = [#oob_x{url = URL}]});
@@ -625,7 +623,7 @@ mod_doc() ->
     #{desc =>
           [?T("This module adds support for https://xmpp.org/extensions/xep-0077.html"
               "[XEP-0077: In-Band Registration]. "
-              "This protocol enables end users to use a XMPP client to:"), "",
+              "This protocol enables end users to use an XMPP client to:"), "",
            ?T("* Register a new account on the server."), "",
            ?T("* Change the password from an existing account on the server."), "",
            ?T("* Delete an existing account on the server."), "",
@@ -636,10 +634,10 @@ mod_doc() ->
           [{access,
             #{value => ?T("AccessName"),
               desc =>
-                  ?T("Specify rules to restrict what usernames can be registered and "
-                     "unregistered. If a rule returns 'deny' on the requested username, "
-                     "registration and unregistration of that user name is denied. "
-                     "There are no restrictions by default.")}},
+                  ?T("Specify rules to restrict what usernames can be registered. "
+                     "If a rule returns 'deny' on the requested username, "
+                     "registration of that user name is denied. There are no "
+                     "restrictions by default.")}},
            {access_from,
             #{value => ?T("AccessName"),
               desc =>
