@@ -5,7 +5,7 @@
 %%% Created :  4 May 2008 by Badlop <badlop@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -60,7 +60,7 @@
 
 -include("logger.hrl").
 
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 
 -include("ejabberd_http.hrl").
 
@@ -115,7 +115,7 @@ process([<<"new">>],
       {success, ok, {Username, Host, _Password}} ->
 	  Jid = jid:make(Username, Host),
           mod_register:send_registration_notifications(?MODULE, Jid, Ip),
-	  Text = translate:translate(Lang, ?T("Your Jabber account was successfully created.")),
+	  Text = translate:translate(Lang, ?T("Your XMPP account was successfully registered.")),
 	  {200, [], Text};
       Error ->
 	  ErrorText =
@@ -128,7 +128,7 @@ process([<<"delete">>],
 		 host = _HTTPHost}) ->
     case form_del_post(Q) of
       {atomic, ok} ->
-	  Text = translate:translate(Lang, ?T("Your Jabber account was successfully deleted.")),
+	  Text = translate:translate(Lang, ?T("Your XMPP account was successfully unregistered.")),
 	  {200, [], Text};
       Error ->
 	  ErrorText =
@@ -143,7 +143,7 @@ process([<<"change_password">>],
 		 host = _HTTPHost}) ->
     case form_changepass_post(Q) of
       {atomic, ok} ->
-	  Text = translate:translate(Lang, ?T("The password of your Jabber account was successfully changed.")),
+	  Text = translate:translate(Lang, ?T("The password of your XMPP account was successfully changed.")),
 	  {200, [], Text};
       Error ->
 	  ErrorText =
@@ -200,7 +200,7 @@ meta() ->
 index_page(Lang) ->
     HeadEls = [meta(),
 	       ?XCT(<<"title">>,
-		    ?T("Jabber Account Registration")),
+		    ?T("XMPP Account Registration")),
 	       ?XA(<<"link">>,
 		   [{<<"href">>, <<"register.css">>},
 		    {<<"type">>, <<"text/css">>},
@@ -208,15 +208,15 @@ index_page(Lang) ->
     Els = [?XACT(<<"h1">>,
 		 [{<<"class">>, <<"title">>},
 		  {<<"style">>, <<"text-align:center;">>}],
-		 ?T("Jabber Account Registration")),
+		 ?T("XMPP Account Registration")),
 	   ?XE(<<"ul">>,
 	       [?XE(<<"li">>,
-		    [?ACT(<<"new/">>, ?T("Register a Jabber account"))]),
+		    [?ACT(<<"new/">>, ?T("Register an XMPP account"))]),
 		?XE(<<"li">>,
 		    [?ACT(<<"change_password/">>, ?T("Change Password"))]),
 		?XE(<<"li">>,
 		    [?ACT(<<"delete/">>,
-			  ?T("Unregister a Jabber account"))])])],
+			  ?T("Unregister an XMPP account"))])])],
     {200,
      [{<<"Server">>, <<"ejabberd">>},
       {<<"Content-Type">>, <<"text/html">>}],
@@ -239,7 +239,7 @@ form_new_get(Host, Lang, IP) ->
 form_new_get2(Host, Lang, CaptchaEls) ->
     HeadEls = [meta(),
 	       ?XCT(<<"title">>,
-		    ?T("Register a Jabber account")),
+		    ?T("Register an XMPP account")),
 	       ?XA(<<"link">>,
 		   [{<<"href">>, <<"../register.css">>},
 		    {<<"type">>, <<"text/css">>},
@@ -247,11 +247,11 @@ form_new_get2(Host, Lang, CaptchaEls) ->
     Els = [?XACT(<<"h1">>,
 		 [{<<"class">>, <<"title">>},
 		  {<<"style">>, <<"text-align:center;">>}],
-		 ?T("Register a Jabber account")),
+		 ?T("Register an XMPP account")),
 	   ?XCT(<<"p">>,
-		?T("This page allows to create a Jabber "
-		   "account in this Jabber server. Your "
-		   "JID (Jabber IDentifier) will be of the "
+		?T("This page allows to register an XMPP "
+		   "account in this XMPP server. Your "
+		   "JID (Jabber ID) will be of the "
 		   "form: username@server. Please read carefully "
 		   "the instructions to fill correctly the "
 		   "fields.")),
@@ -281,19 +281,19 @@ form_new_get2(Host, Lang, CaptchaEls) ->
 			    ?XE(<<"ul">>,
 				[?XCT(<<"li">>,
 				      ?T("Don't tell your password to anybody, "
-					 "not even the administrators of the Jabber "
+					 "not even the administrators of the XMPP "
 					 "server.")),
 				 ?XCT(<<"li">>,
 				      ?T("You can later change your password using "
-					 "a Jabber client.")),
+					 "an XMPP client.")),
 				 ?XCT(<<"li">>,
-				      ?T("Some Jabber clients can store your password "
+				      ?T("Some XMPP clients can store your password "
 					 "in the computer, but you should do this only "
 					 "in your personal computer for safety reasons.")),
 				 ?XCT(<<"li">>,
 				      ?T("Memorize your password, or write it "
 					 "in a paper placed in a safe place. In "
-					 "Jabber there isn't an automated way "
+					 "XMPP there isn't an automated way "
 					 "to recover your password if you forget "
 					 "it."))])]),
 		       ?XE(<<"li">>,
@@ -494,7 +494,7 @@ check_password(Username, Host, Password) ->
 form_del_get(Host, Lang) ->
     HeadEls = [meta(),
 	       ?XCT(<<"title">>,
-		    ?T("Unregister a Jabber account")),
+		    ?T("Unregister an XMPP account")),
 	       ?XA(<<"link">>,
 		   [{<<"href">>, <<"../register.css">>},
 		    {<<"type">>, <<"text/css">>},
@@ -502,10 +502,10 @@ form_del_get(Host, Lang) ->
     Els = [?XACT(<<"h1">>,
 		 [{<<"class">>, <<"title">>},
 		  {<<"style">>, <<"text-align:center;">>}],
-		 ?T("Unregister a Jabber account")),
+		 ?T("Unregister an XMPP account")),
 	   ?XCT(<<"p">>,
-		?T("This page allows to unregister a Jabber "
-		   "account in this Jabber server.")),
+		?T("This page allows to unregister an XMPP "
+		   "account in this XMPP server.")),
 	   ?XAE(<<"form">>,
 		[{<<"action">>, <<"">>}, {<<"method">>, <<"post">>}],
 		[?XE(<<"ol">>,
@@ -608,7 +608,7 @@ get_error_text({error, not_allowed}) ->
 get_error_text({error, account_doesnt_exist}) ->
     ?T("Account doesn't exist");
 get_error_text({error, account_exists}) ->
-    ?T("The account was not deleted");
+    ?T("The account was not unregistered");
 get_error_text({error, password_not_changed}) ->
     ?T("The password was not changed");
 get_error_text({error, passwords_not_identical}) ->
@@ -624,7 +624,7 @@ mod_doc() ->
           [?T("This module provides a web page where users can:"), "",
            ?T("- Register a new account on the server."), "",
            ?T("- Change the password from an existing account on the server."), "",
-           ?T("- Delete an existing account on the server."), "",
+           ?T("- Unregister an existing account on the server."), "",
 	   ?T("This module supports CAPTCHA image to register a new account. "
 	      "To enable this feature, configure the options 'captcha\_cmd' "
 	      "and 'captcha\_url', which are documented in the section with "
