@@ -7,7 +7,7 @@
 %%% Created :  5 Mar 2005 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -43,13 +43,14 @@
 	 depends/2, mod_doc/0]).
 
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("mod_roster.hrl").
 -include("eldap.hrl").
 -include("translate.hrl").
 
 -define(USER_CACHE, shared_roster_ldap_user_cache).
 -define(GROUP_CACHE, shared_roster_ldap_group_cache).
+-define(DISPLAYED_CACHE, shared_roster_ldap_displayed_cache).
 -define(LDAP_SEARCH_TIMEOUT, 5).    %% Timeout for LDAP search queries in seconds
 -define(INVALID_SETTING_MSG, "~ts is not properly set! ~ts will not function.").
 
@@ -76,7 +77,8 @@
          ufilter = <<"">>                             :: binary(),
          rfilter = <<"">>                             :: binary(),
          gfilter = <<"">>                             :: binary(),
-	 auth_check = true                            :: boolean()}).
+         user_jid_attr = <<"">>                       :: binary(),
+         auth_check = true                            :: boolean()}).
 
 -record(group_info, {desc, members}).
 
@@ -93,7 +95,8 @@ reload(Host, NewOpts, _OldOpts) ->
     case init_cache(Host, NewOpts) of
 	true ->
 	    ets_cache:setopts(?USER_CACHE, cache_opts(Host, NewOpts)),
-	    ets_cache:setopts(?GROUP_CACHE, cache_opts(Host, NewOpts));
+	    ets_cache:setopts(?GROUP_CACHE, cache_opts(Host, NewOpts)),
+	    ets_cache:setopts(?DISPLAYED_CACHE, cache_opts(Host, NewOpts));
 	false ->
 	    ok
     end,
@@ -306,6 +309,13 @@ eldap_search(State, FilterParseArgs, AttributesList) ->
 
 get_user_displayed_groups({User, Host}) ->
     {ok, State} = eldap_utils:get_state(Host, ?MODULE),
+    ets_cache:lookup(?DISPLAYED_CACHE,
+		     {User, Host},
+		     fun () ->
+			 search_user_displayed_groups(State, User)
+		     end).
+
+search_user_displayed_groups(State, User) ->
     GroupAttr = State#state.group_attr,
     Entries = eldap_search(State,
 			   [eldap_filter:do_sub(State#state.rfilter,
@@ -387,6 +397,24 @@ search_group_info(State, Group) ->
 	  {ok, #group_info{desc = GroupDesc, members = lists:usort(lists:flatten(MembersLists))}}
     end.
 
+get_member_jid(#state{user_jid_attr = <<>>}, UID, Host) ->
+    {jid:nodeprep(UID), Host};
+get_member_jid(#state{user_jid_attr = UserJIDAttr, user_uid = UIDAttr} = State,
+               UID, Host) ->
+    Entries = eldap_search(State,
+                           [eldap_filter:do_sub(<<"(", UIDAttr/binary, "=%u)">>,
+                                                [{<<"%u">>, UID}])],
+                           [UserJIDAttr]),
+    case Entries of
+        [] ->
+            {error, error};
+        [#eldap_entry{attributes = [{UserJIDAttr, [MemberJID | _]}]} | _] ->
+            case jid:decode(MemberJID) of
+                error -> {error, Host};
+                #jid{luser = U, lserver = S} -> {U, S}
+            end
+    end.
+
 extract_members(State, Extractor, AuthChecker, #eldap_entry{attributes = Attrs}, {DescAcc, JIDsAcc}) ->
     Host = State#state.host,
     case {eldap_utils:get_ldap_attr(State#state.group_attr, Attrs),
@@ -394,23 +422,22 @@ extract_members(State, Extractor, AuthChecker, #eldap_entry{attributes = Attrs},
           lists:keysearch(State#state.uid, 1, Attrs)} of
         {ID, Desc, {value, {GroupMemberAttr, Members}}} when ID /= <<"">>,
                                                              GroupMemberAttr == State#state.uid ->
-            JIDs = lists:foldl(fun({ok, UID}, L) ->
-                                       PUID = jid:nodeprep(UID),
-                                       case PUID of
-                                           error ->
-                                               L;
-                                           _ ->
-                                               case AuthChecker(PUID, Host) of
-                                                   true ->
-                                                       [{PUID, Host} | L];
-                                                   _ ->
-                                                       L
-                                               end
-                                       end;
-                                  (_, L) -> L
-                               end,
-                               [],
-                               lists:map(Extractor, Members)),
+            JIDs = lists:foldl(
+                fun({ok, UID}, L) ->
+                    {MemberUID, MemberHost} = get_member_jid(State, UID, Host),
+                    case MemberUID of
+                        error ->
+                            L;
+                        _ ->
+                            case AuthChecker(MemberUID, MemberHost) of
+                                true ->
+                                    [{MemberUID, MemberHost} | L];
+                                _ ->
+                                    L
+                            end
+                    end;
+                   (_, L) -> L
+                end, [], lists:map(Extractor, Members)),
             {Desc, [JIDs | JIDsAcc]};
         _ ->
             {DescAcc, JIDsAcc}
@@ -456,6 +483,7 @@ parse_options(Host, Opts) ->
     UIDAttr = mod_shared_roster_ldap_opt:ldap_memberattr(Opts),
     UIDAttrFormat = mod_shared_roster_ldap_opt:ldap_memberattr_format(Opts),
     UIDAttrFormatRe = mod_shared_roster_ldap_opt:ldap_memberattr_format_re(Opts),
+    JIDAttr = mod_shared_roster_ldap_opt:ldap_userjidattr(Opts),
     AuthCheck = mod_shared_roster_ldap_opt:ldap_auth_check(Opts),
     ConfigFilter = mod_shared_roster_ldap_opt:ldap_filter(Opts),
     ConfigUserFilter = mod_shared_roster_ldap_opt:ldap_ufilter(Opts),
@@ -500,6 +528,7 @@ parse_options(Host, Opts) ->
            base = Cfg#eldap_config.base,
            deref_aliases = Cfg#eldap_config.deref_aliases,
 	   uid = UIDAttr,
+           user_jid_attr = JIDAttr,
 	   group_attr = GroupAttr, group_desc = GroupDesc,
 	   user_desc = UserDesc, user_uid = UserUID,
 	   uid_format = UIDAttrFormat,
@@ -513,10 +542,12 @@ init_cache(Host, Opts) ->
 	true ->
 	    CacheOpts = cache_opts(Host, Opts),
 	    ets_cache:new(?USER_CACHE, CacheOpts),
-	    ets_cache:new(?GROUP_CACHE, CacheOpts);
+	    ets_cache:new(?GROUP_CACHE, CacheOpts),
+	    ets_cache:new(?DISPLAYED_CACHE, CacheOpts);
 	false ->
 	    ets_cache:delete(?USER_CACHE),
-	    ets_cache:delete(?GROUP_CACHE)
+	    ets_cache:delete(?GROUP_CACHE),
+	    ets_cache:delete(?DISPLAYED_CACHE)
     end,
     UseCache.
 
@@ -551,6 +582,8 @@ mod_opt_type(ldap_userdesc) ->
     econf:binary();
 mod_opt_type(ldap_useruid) ->
     econf:binary();
+mod_opt_type(ldap_userjidattr) ->
+    econf:binary();
 mod_opt_type(ldap_backups) ->
     econf:list(econf:domain(), [unique]);
 mod_opt_type(ldap_base) ->
@@ -607,6 +640,7 @@ mod_options(Host) ->
      {ldap_ufilter, <<"">>},
      {ldap_userdesc, <<"cn">>},
      {ldap_useruid, <<"cn">>},
+     {ldap_userjidattr, <<"">>},
      {ldap_backups, ejabberd_option:ldap_backups(Host)},
      {ldap_base, ejabberd_option:ldap_base(Host)},
      {ldap_uids, ejabberd_option:ldap_uids(Host)},
@@ -730,6 +764,12 @@ mod_doc() ->
 		     "'ldap_memberattr' attribute of a group object. "
 		     "Retrieved from results of the \"User Filter\". "
 		     "Defaults to 'cn'.")}},
+           {ldap_userjidattr,
+            #{desc =>
+              ?T("The name of the attribute which is used to map user id "
+                 "to XMPP jid. If not specified (and that is default value "
+                 "of this option), user jid will be created from user id and "
+                 " this module host.")}},
 	   %% Control parameters:
            {ldap_memberattr_format,
             #{desc =>
