@@ -5,7 +5,7 @@
 %%% Created :  2 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -44,7 +44,7 @@
 -export([route/1]).
 
 -include("logger.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("mod_vcard.hrl").
 -include("translate.hrl").
 -include("ejabberd_stacktrace.hrl").
@@ -210,7 +210,7 @@ process_local_iq(#iq{type = get, to = To, lang = Lang} = IQ) ->
 		undefined ->
 		    #vcard_temp{fn = <<"ejabberd">>,
 				url = ejabberd_config:get_uri(),
-				desc = misc:get_descr(Lang, ?T("Erlang Jabber Server")),
+				desc = misc:get_descr(Lang, ?T("Erlang XMPP Server")),
 				bday = <<"2002-11-16">>};
 		V ->
 		    V
@@ -456,7 +456,7 @@ make_instructions(Mod, Lang) ->
     Fill = translate:translate(
 	     Lang,
 	     ?T("Fill in the form to search for any matching "
-		"Jabber User")),
+		"XMPP User")),
     Add = translate:translate(
 	    Lang,
 	    ?T(" (Add * to the end of field to match substring)")),
