@@ -4,7 +4,7 @@
 %%% Created : 29 Jul 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2020   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2021   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -40,7 +40,7 @@
 
 -include("logger.hrl").
 -include("eldap.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 -include("translate.hrl").
 
 -define(PROCNAME, ejabberd_mod_vcard_ldap).
@@ -531,7 +531,7 @@ mod_doc() ->
 		  ?T("With this option you can set the table that maps LDAP "
 		     "attributes to vCard fields. 'Name' is the type name of "
 		     "the vCard as defined in "
-		     "http://tools.ietf.org/html/rfc2426[RFC 2426]. "
+		     "https://tools.ietf.org/html/rfc2426[RFC 2426]. "
 		     "'Pattern' is a string which contains "
 		     "pattern variables '%u', '%d' or '%s'. "
 		     "'LDAPattributes' is the list containing LDAP attributes. "
